==> com.liferay.layout.content.page.editor.web-1.0.20.jar: META-INF/resources/js/components/floating_toolbar/common/FloatingToolbarColorPicker.es.js <==
"use strict";

Liferay.Loader.define("layout-content-page-editor-web@1.0.20/js/components/floating_toolbar/common/FloatingToolbarColorPicker.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-state', 'frontend-js-metal-web$metal-soy', './FloatingToolbarColorPicker.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = exports.FloatingToolbarColorPicker = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _FloatingToolbarColorPicker = _interopRequireDefault(require("./FloatingToolbarColorPicker.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * FloatingToolbarColorPicker
   */
  var FloatingToolbarColorPicker =
  /*#__PURE__*/
  function (_Component) {
    _inherits(FloatingToolbarColorPicker, _Component);

    function FloatingToolbarColorPicker() {
      _classCallCheck(this, FloatingToolbarColorPicker);

      return _possibleConstructorReturn(this, _getPrototypeOf(FloatingToolbarColorPicker).apply(this, arguments));
    }

    _createClass(FloatingToolbarColorPicker, [{
      key: "_handleColorButtonClick",

      /**
       * Continues the propagation of the color button clicked event
       * @param {Event} event
       * @private
       * @review
       */
      value: function _handleColorButtonClick(event) {
        this.emit('colorClicked', {
          color: event.delegateTarget.dataset.backgroundColorCssClass
        });
      }
    }]);

    return FloatingToolbarColorPicker;
  }(_metalComponent.default);
  /**
   * State definition.
   * @review
   * @static
   * @type {!Object}
   */

  exports.FloatingToolbarColorPicker = FloatingToolbarColorPicker;
  FloatingToolbarColorPicker.STATE = {
    /**
     * Available colors
     * @instance
     * @memberof FloatingToolbarColorPicker
     * @review
     * @type {Array}
     */
    colors: _metalState.Config.array().required(),

    /**
     * Selected color
     * @instance
     * @memberof FloatingToolbarColorPicker
     * @review
     * @type {string}
     */
    selectedColor: _metalState.Config.string(),

    /**
     * Show clear button or not
     * @instance
     * @memberof FloatingToolbarColorPicker
     * @review
     * @type {boolean}
     */
    showClearButton: _metalState.Config.bool(false)
  };

  _metalSoy.default.register(FloatingToolbarColorPicker, _FloatingToolbarColorPicker.default);

  var _default = FloatingToolbarColorPicker;
  exports.default = _default;
  //# sourceMappingURL=FloatingToolbarColorPicker.es.js.map
});
//# sourceMappingURL=FloatingToolbarColorPicker.es.js.map

==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/components/floating_toolbar/common/FloatingToolbarColorPicker.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.52/js/components/floating_toolbar/common/FloatingToolbarColorPicker.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', './FloatingToolbarColorPicker.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.FloatingToolbarColorPicker = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  var _FloatingToolbarColorPicker = _interopRequireDefault(require("./FloatingToolbarColorPicker.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * FloatingToolbarColorPicker
   */
  var FloatingToolbarColorPicker =
  /*#__PURE__*/
  function (_Component) {
    _inherits(FloatingToolbarColorPicker, _Component);

    function FloatingToolbarColorPicker() {
      _classCallCheck(this, FloatingToolbarColorPicker);

      return _possibleConstructorReturn(this, _getPrototypeOf(FloatingToolbarColorPicker).apply(this, arguments));
    }

    _createClass(FloatingToolbarColorPicker, [{
      key: "_handleColorButtonClick",

      /**
       * Continues the propagation of the color button clicked event
       * @param {Event} event
       * @private
       * @review
       */
      value: function _handleColorButtonClick(event) {
        this.emit('colorClicked', {
          color: event.delegateTarget.dataset.backgroundColorCssClass
        });
      }
    }]);

    return FloatingToolbarColorPicker;
  }(_metalComponent["default"]);
  /**
   * State definition.
   * @review
   * @static
   * @type {!Object}
   */

  exports.FloatingToolbarColorPicker = FloatingToolbarColorPicker;
  FloatingToolbarColorPicker.STATE = {
    /**
     * Available colors
     * @instance
     * @memberof FloatingToolbarColorPicker
     * @review
     * @type {Array}
     */
    colors: _metalState.Config.array().required(),

    /**
     * Selected color
     * @instance
     * @memberof FloatingToolbarColorPicker
     * @review
     * @type {string}
     */
    selectedColor: _metalState.Config.string(),

    /**
     * Show clear button or not
     * @instance
     * @memberof FloatingToolbarColorPicker
     * @review
     * @type {boolean}
     */
    showClearButton: _metalState.Config.bool(false)
  };

  _metalSoy["default"].register(FloatingToolbarColorPicker, _FloatingToolbarColorPicker["default"]);

  var _default = FloatingToolbarColorPicker;
  exports["default"] = _default;
  //# sourceMappingURL=FloatingToolbarColorPicker.es.js.map
});
//# sourceMappingURL=FloatingToolbarColorPicker.es.js.map
